pub struct Colliding {
pub contact: Contact,
pub restitution: f64,
}Expand description
A “TOI contact”.
A pair of objects together with a contact plane and non-negative restitution value.
A resting contact will have a restitution value of 0.0 and a colliding contact will usually have a positive non-zero restitution value.
⚠ Note that the PartialOrd and Ord implementations are only so
that contacts can be sorted in the narrow TOI list. Attempting to compare
contacts will always panic.
Fields
contact: Contactrestitution: f64Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Colliding
impl<'de> Deserialize<'de> for Colliding
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Ord for Colliding
impl Ord for Colliding
Sourceimpl PartialOrd for Colliding
impl PartialOrd for Colliding
Sourcefn partial_cmp(&self, _rhs: &Self) -> Option<Ordering>
fn partial_cmp(&self, _rhs: &Self) -> Option<Ordering>
Panics: should not be called; this trait is implemented so that narrow TOI results can be automatically be sorted
impl Eq for Colliding
impl StructuralPartialEq for Colliding