pub struct Material {
pub restitution: f64,
pub friction: f64,
}Expand description
Surface material properties
Fields
restitution: f64A generic restitution is in [0.0,1.0] with 1.0 being perfectly elastic and 0.0 perfectly inelastic.
When a pair of material objects collide, their respective restitution coefficients are multiplied to give the restitution coefficient for that collision.
friction: f64A generic friction coefficient is in [0.0,\infty] with 0.0 being perfectly frictionless and 1.0 being about equivalent to concrete on rubber.
When a pair of material objects have contact, the average of their respective friction coefficients is computed to give the friction coefficient for that contact.