pub struct Tetrahedron3<S> { /* private fields */ }Expand description
A 3-simplex or tetrahedron in 3D space
Creation methods will fail with a debug assertion if the points are coplanar.
Implementations
Sourceimpl<S> Tetrahedron<S>where
S: OrderedField,
impl<S> Tetrahedron<S>where
S: OrderedField,
Sourcepub fn new(
a: Point3<S>,
b: Point3<S>,
c: Point3<S>,
d: Point3<S>,
) -> Option<Tetrahedron<S>>where
S: AbsDiffEq<Epsilon = S>,
pub fn new(
a: Point3<S>,
b: Point3<S>,
c: Point3<S>,
d: Point3<S>,
) -> Option<Tetrahedron<S>>where
S: AbsDiffEq<Epsilon = S>,
Returns None if the points are coplanar:
assert!(Tetrahedron::new (
[-1.0, -1.0, -1.0].into(),
[ 1.0, 1.0, 1.0].into(),
[-1.0, 1.0, 0.0].into(),
[ 1.0, -1.0, 0.0].into()
).is_none());Sourcepub fn noisy(
a: Point3<S>,
b: Point3<S>,
c: Point3<S>,
d: Point3<S>,
) -> Tetrahedron<S>where
S: AbsDiffEq<Epsilon = S>,
pub fn noisy(
a: Point3<S>,
b: Point3<S>,
c: Point3<S>,
d: Point3<S>,
) -> Tetrahedron<S>where
S: AbsDiffEq<Epsilon = S>,
Panics if the points are coplanar:
let s = Tetrahedron::noisy (
[-1.0, -1.0, -1.0].into(),
[ 1.0, 1.0, 1.0].into(),
[-1.0, 1.0, 0.0].into(),
[ 1.0, -1.0, 0.0].into());Sourcepub fn unchecked(
a: Point3<S>,
b: Point3<S>,
c: Point3<S>,
d: Point3<S>,
) -> Tetrahedron<S>where
S: AbsDiffEq<Epsilon = S>,
pub fn unchecked(
a: Point3<S>,
b: Point3<S>,
c: Point3<S>,
d: Point3<S>,
) -> Tetrahedron<S>where
S: AbsDiffEq<Epsilon = S>,
Debug panic if the points are coplanar:
let s = Tetrahedron::unchecked (
[-1.0, -1.0, -1.0].into(),
[ 1.0, 1.0, 1.0].into(),
[-1.0, 1.0, 0.0].into(),
[ 1.0, -1.0, 0.0].into());pub fn from_array(_: [Point3<S>; 4]) -> Option<Tetrahedron<S>>where
S: AbsDiffEq<Epsilon = S>,
pub const fn point_a(self) -> Point3<S>
pub const fn point_b(self) -> Point3<S>
pub const fn point_c(self) -> Point3<S>
pub const fn point_d(self) -> Point3<S>
pub const fn points(self) -> [Point3<S>; 4]
pub const fn edge_ab(self) -> Segment<S>
pub const fn edge_ac(self) -> Segment<S>
pub const fn edge_ad(self) -> Segment<S>
pub const fn edge_bc(self) -> Segment<S>
pub const fn edge_bd(self) -> Segment<S>
pub const fn edge_cd(self) -> Segment<S>
pub const fn edges(self) -> [Segment<S>; 6]
Sourcepub fn face_abc(self) -> Triangle<S>
pub fn face_abc(self) -> Triangle<S>
Note that the points in the returned triangle will be ordered so that the
triangle.normal() will face away from the tetrahedron.
Sourcepub fn face_abd(self) -> Triangle<S>
pub fn face_abd(self) -> Triangle<S>
Note that the points in the returned triangle will be ordered so that the
triangle.normal() will face away from the tetrahedron.
Sourcepub fn face_acd(self) -> Triangle<S>
pub fn face_acd(self) -> Triangle<S>
Note that the points in the returned triangle will be ordered so that the
triangle.normal() will face away from the tetrahedron.
Sourcepub fn face_bcd(self) -> Triangle<S>
pub fn face_bcd(self) -> Triangle<S>
Note that the points in the returned triangle will be ordered so that the
triangle.normal() will face away from the tetrahedron.
pub fn faces(self) -> [Triangle<S>; 4]
pub fn normal_abc(self) -> NonZero3<S>
pub fn normal_abd(self) -> NonZero3<S>
pub fn normal_acd(self) -> NonZero3<S>
pub fn normal_bcd(self) -> NonZero3<S>
pub fn volume(self) -> Positive<S>
pub fn translate(&mut self, displacement: Vec3<S>)
Sourcepub fn contains(self, point: Point3<S>) -> bool
pub fn contains(self, point: Point3<S>) -> bool
Checks if a point is contained in the tetrahedron:
let s = Tetrahedron::noisy (
[ 0.0, 0.0, 1.0].into(),
[ 0.0, 1.0, -1.0].into(),
[-1.0, -1.0, -1.0].into(),
[ 1.0, -1.0, -1.0].into()
);
assert!(s.contains (Point3::origin()));
assert!(!s.contains ([0.0, 0.0, 2.0].into()));Trait Implementations
Sourceimpl<S> Clone for Tetrahedron<S>where
S: Clone,
impl<S> Clone for Tetrahedron<S>where
S: Clone,
Sourcefn clone(&self) -> Tetrahedron<S>
fn clone(&self) -> Tetrahedron<S>
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl<S> Debug for Tetrahedron<S>where
S: Debug,
impl<S> Debug for Tetrahedron<S>where
S: Debug,
Sourceimpl<S> Default for Tetrahedron<S>
impl<S> Default for Tetrahedron<S>
Sourcefn default() -> Tetrahedron<S>
fn default() -> Tetrahedron<S>
A default simplex is arbitrarily chosen to be the simplex with vertices at unit
distance from the origin with A at [0.0, 0.0, 1.0] and B at
[0.0, sqrt(8.0/9.0), -1.0/3.0], and points C and D at
[ sqrt(2.0/3.0), -sqrt(2.0/9.0), -1.0/3.0] and
[-sqrt(2.0/3.0), -sqrt(2.0/9.0), -1.0/3.0].
let s = Tetrahedron::default();
let t = Tetrahedron::noisy (
[ 0.0, 0.0, 1.0].into(),
[ 0.0, f64::sqrt(8.0/9.0), -1.0/3.0].into(),
[ f64::sqrt(2.0/3.0), -f64::sqrt(2.0/9.0), -1.0/3.0].into(),
[-f64::sqrt(2.0/3.0), -f64::sqrt(2.0/9.0), -1.0/3.0].into());
approx::assert_relative_eq!(
Matrix4::from_col_arrays ([
s.point_a().0.with_w (0.0).into_array(),
s.point_b().0.with_w (0.0).into_array(),
s.point_c().0.with_w (0.0).into_array(),
s.point_d().0.with_w (0.0).into_array()
]),
Matrix4::from_col_arrays ([
t.point_a().0.with_w (0.0).into_array(),
t.point_b().0.with_w (0.0).into_array(),
t.point_c().0.with_w (0.0).into_array(),
t.point_d().0.with_w (0.0).into_array()
]));Sourceimpl<'de, S> Deserialize<'de> for Tetrahedron<S>where
S: Deserialize<'de>,
impl<'de, S> Deserialize<'de> for Tetrahedron<S>where
S: Deserialize<'de>,
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<Tetrahedron<S>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Tetrahedron<S>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Sourceimpl<S> From<Tetrahedron<S>> for Hull3<S>where
S: Real + RelativeEq<Epsilon = S>,
impl<S> From<Tetrahedron<S>> for Hull3<S>where
S: Real + RelativeEq<Epsilon = S>,
Sourcefn from(tetrahedron: Tetrahedron<S>) -> Hull3<S>
fn from(tetrahedron: Tetrahedron<S>) -> Hull3<S>
Sourceimpl<S> PartialEq for Tetrahedron<S>where
S: PartialEq,
impl<S> PartialEq for Tetrahedron<S>where
S: PartialEq,
Sourcefn eq(&self, other: &Tetrahedron<S>) -> bool
fn eq(&self, other: &Tetrahedron<S>) -> bool
self and other values to be equal, and is used by ==.Sourceimpl<S> Serialize for Tetrahedron<S>where
S: Serialize,
impl<S> Serialize for Tetrahedron<S>where
S: Serialize,
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Sourceimpl<S> TryFrom<[Point3<S>; 4]> for Tetrahedron<S>where
S: OrderedField + RelativeEq<Epsilon = S>,
impl<S> TryFrom<[Point3<S>; 4]> for Tetrahedron<S>where
S: OrderedField + RelativeEq<Epsilon = S>,
impl<S> Copy for Tetrahedron<S>where
S: Copy,
impl<S> Eq for Tetrahedron<S>where
S: Eq,
impl<S> StructuralPartialEq for Tetrahedron<S>