Collision detection and resolution
Re-exports
pub use self::contact::Contact;pub use self::proximity::Proximity;pub use self::intersection::Intersection;
Modules
Structs
- Collision
- Collision subsystem
Constants
- CONTACT_
DISTANCE - Distance criterea for contacts and collisions (TOI contacts).
- OBJECT_
KEY_ MAX - The value of the dynamic bit also gives the maximum key value allowed for objects in the collision system.
- RESTING_
VELOCITY - Velocity for determination of whether a normal impulse should be applied