Module object

Module object 

Simulation object entities.

Each object is uniquely identified by an Id consisting of the object Kind and the object Key.

Structs

Dynamic
A free, bounded, massive object
Id
Each value identifies a unique object by the kind of object and its key
Key
A VecMap index
Nodetect
A free, massive object
Static
A fixed, bounded object

Enums

Kind
Object kind
Variant
One of object variants
VariantRef
Reference to one of object variants

Constants

KEY_MAX

Traits

Bounded
A bounded object
Inertial
Inertial object
Massive
A bounded object with mass
Object
Base object trait
Solid
A bounded object with material properties
Temporal
Object with time derivatives

Functions

report_sizes
Print object size information

Type Aliases

KeyType
Object keys are used to uniquely identify an object of a specific kind: static, dynamic, or nodetect.